part of dashboard;

class DashboardItem {
  final String id;
  final String label;
  final Widget icon;
  final Widget? selectedIcon;
  final Widget Function()? _builder;
  final List<NavigatorItem> _navigatorPages;
  final void Function(String? value)? search;
  final AppBarOptions? appBarOptions;
  final List<DashboardItem> subItems;
  final bool addNavigator;

  /// {@macro flutter.material.appBar.actions}
  ///
  /// This property is used to configure an [AppBar].
  final List<Widget> actions;

  final bool overrideActions;
  bool get hasBuilder => _builder != null || _navigatorPages.isNotEmpty;
  DashboardItem({
    required this.label,
    required this.id,
    required Widget Function() builder,
    required this.icon,
    this.appBarOptions,
    this.selectedIcon,
    this.search,
    this.overrideActions = false,
    this.actions = const [],
    this.addNavigator = true,
  })  : subItems = [],
        _builder = builder,
        _navigatorPages = [];

  DashboardItem.withNavigator({
    required this.label,
    required this.id,
    required List<NavigatorItem> pages,
    required this.icon,
    this.appBarOptions,
    this.selectedIcon,
    this.search,
    this.overrideActions = false,
    this.actions = const [],
    this.addNavigator = true,
  })  : subItems = [],
        assert(pages.isNotEmpty),
        _builder = null,
        _navigatorPages = pages;
  DashboardItem.items({
    required this.label,
    required this.icon,
    required this.subItems,
  })  : selectedIcon = null,
        appBarOptions = null,
        id = '',
        addNavigator = false,
        search = null,
        overrideActions = false,
        actions = const [],
        _builder = null,
        _navigatorPages = [];
}

class PageInfo extends StatefulWidget {
  final DashboardItem item;
  final List<TextSpan> titleSpans;

  const PageInfo({
    Key? key,
    required this.item,
    required this.titleSpans,
  }) : super(key: key);
  @override
  State<PageInfo> createState() => _PageInfoState();

  static PageInfo? of(BuildContext context) =>
      context.findAncestorStateOfType<_PageInfoState>()?.widget;
}

class _PageInfoState extends State<PageInfo> {
  @override
  Widget build(BuildContext context) {
    if (widget.item._builder != null) {
      return widget.item._builder!();
    }

    return Navigator(
      initialRoute: widget.item._navigatorPages.first.name,
      onGenerateRoute: (settings) {
        var pages = widget.item._navigatorPages
            .where((element) => element.name == settings.name);
        if (pages.isEmpty) {
          return Navigator.of(context).widget.onGenerateRoute?.call(settings);
        }
        return MaterialPageRoute(
          builder: pages.first.builder,
          settings: settings,
        );
      },
    );
  }
}

class NavigatorItem {
  final String name;
  final Widget Function(BuildContext context) builder;

  NavigatorItem({
    required this.name,
    required this.builder,
  });
}
